@@ -289,12 +289,23 @@ class Theme(models.Model):
         verbose_name=_('close button visible'))
 
     list_filter_dropdown = models.BooleanField(
-        default=False,
+        default=True,
         verbose_name=_('use dropdown'))
+    list_filter_sticky = models.BooleanField(
+        default=True,
+        verbose_name=_('sticky position'))
+
     recent_actions_visible = models.BooleanField(
         default=True,
         verbose_name=_('visible'))
 
+    form_submit_sticky = models.BooleanField(
+        default=False,
+        verbose_name=_('sticky submit'))
+    form_pagination_sticky = models.BooleanField(
+        default=False,
+        verbose_name=_('sticky pagination'))
+
     def set_active(self):
         self.active = True
         self.save()
